Authors
=======
The following have contributed to the development, maintenance, and/or testing of ``bio2bel_interpro``.

Maintainer
----------
`Charles Tapley Hoyt <https://github.com/cthoyt>`_

Code Contributors
-----------------
- `Aram Grigoryan <https://github.com/aramgrigoryan>`_
